pub struct Assignment<AccountId, P>where
P: PerThing,{
pub who: AccountId,
pub distribution: Vec<(AccountId, P)>,
}Expand description
A voter’s stake assignment among a set of targets, represented as ratios.
Fields
who: AccountIdVoter’s identifier.
distribution: Vec<(AccountId, P)>The distribution of the voter’s stake.
Implementations
Sourceimpl<AccountId, P> Assignment<AccountId, P>where
AccountId: IdentifierT,
P: PerThing128,
impl<AccountId, P> Assignment<AccountId, P>where
AccountId: IdentifierT,
P: PerThing128,
Sourcepub fn into_staked(self, stake: u128) -> StakedAssignment<AccountId>
pub fn into_staked(self, stake: u128) -> StakedAssignment<AccountId>
Convert from a ratio assignment into one with absolute values aka. StakedAssignment.
It needs stake which is the total budget of the voter.
Note that this might create un-normalized assignments, due to accuracy loss of P. Call
site might compensate by calling try_normalize() on the returned StakedAssignment as a
post-precessing.
If an edge ratio is Bounded::min_value(), it is dropped. This edge can never mean
anything useful.
Sourcepub fn try_normalize(&mut self) -> Result<(), &'static str>
pub fn try_normalize(&mut self) -> Result<(), &'static str>
Try and normalize this assignment.
If Ok(()) is returned, then the assignment MUST have been successfully normalized to 100%.
Errors
This will return only if the internal normalize fails. This can happen if sum of
self.distribution.map(|p| p.deconstruct()) fails to fit inside UpperOf<P>. A user of
this crate may statically assert that this can never happen and safely expect this to
return Ok.